# importing modules
import sys as sys
import os 
import pandas as pd 
import matplotlib.pyplot as plt
# Getting the name of the directory where this file is present.
current = os.path.dirname(os.path.realpath(__file__))  # src
# Getting the parent directory name where the current directory is present.
parent = os.path.dirname(current) # Simulation
# Getting the grandparent directory name
gparent = os.path.dirname(parent) # SinglePASMC
# The path where the plotExp.py is saved
mpath = gparent + '\\cellLib\\Scripts'
# appending a path
sys.path.append(mpath)
import plotExp
# The properties of traces
colors=plt.rcParams['axes.prop_cycle'].by_key()['color']
lines = ['-','--','-.',':']
markers = ['.',',','o','+','x','d']
# Figure file name and titles
figfiles=parent+'\\simFig4_1.png'
fig_title = 'Dynamics when $K_{out}=5.9$ mM'
plot_title =['$K_{out}$','$Ca^{2+}$ concentration in the SR','$Ca^{2+}$ concentration in the cytosol','The cell membrane potential',]
labels = ['$c_{i0}=0.1$,$s_{i0}=1.06$,$v_{i0}=-28$']
# Data source
dfolder_sim=parent+'\\simulatedData\\'
x_var_sim = 't'
y_vars_sim = ['output/K_out','output/s_i','output/c_i', 'output/v_i',]
x_label='t(s)'
y_label=['$K_{out}(mM)$','$s_{i}(\mu M)$','$c_{i}(\mu M)$','$v_{i}(mV)$']
# Build the traces
number_trace = 1
number_plot = len(y_vars_sim)
trace = [[0] * number_trace for i in range(number_plot)]

for plotid, y_var_sim in enumerate(y_vars_sim):
   for traceid in range(number_trace):
      filename='simFig4_4.csv'       
      dfile = dfolder_sim + filename  
      data = pd.read_csv(dfile)
      x_data=data[x_var_sim].values
      y_data=data[y_var_sim].values     
      trace[plotid][traceid]={'dataX': x_data, 'dataY': y_data, 'lname': labels[traceid], 'linestyle':lines[0], 'marker':None, 'linecolor':colors[traceid],'y2':False}
# Build the plots 
# maxH=8.75 inches, width 2.63-7.5
rows,cols = 2,2
left = 0.125  # the left side of the subplots of the figure,0.125
right = 0.9   # the right side of the subplots of the figure,0.9
bottom = 0.1  # the bottom of the subplots of the figure, 0.1
top = 0.75     # the top of the subplots of the figure 0.9
wspace = 0.4  # the amount of width reserved for space between subplots,
              # expressed as a fraction of the average axis width, 0.2
hspace = 0.6  # the amount of height reserved for space between subplots,
              # expressed as a fraction of the average axis height, 0.2
lgdfont, labelfont =10, 10
width, height= cols*3.5, rows*3
figs ={ 'width':width, 'height': height, 'rows': rows, 'cols': cols,'left':left,'bottom':bottom,'right':right,'top':top,'wspace': wspace,'hspace': hspace,'fig_title':fig_title,'title_y':1}

plots=[]
for id in range(4):    
   colid = id%2
   rowid = id//2
   if id == 2:
      lgdshow = True
      bbox_to_anchor = (2,3.4)
   else:
      lgdshow = False
      bbox_to_anchor = None      
   iplot={'rowid':rowid, 'colid':colid, 'xlabel': x_label, 'ylabel':y_label[id], 'twiny':False,    'ylabel2':y_label[id],'labelcolor':colors[1],
            'lgdshow': lgdshow, 'lgdloc':'best', 'bbox_to_anchor':bbox_to_anchor,'lgdncol': 2, 'lgdfont':lgdfont, 'labelfont': labelfont,  
            'setxlim': False, 'xmin':0, 'xmax': 1, 'setylim': False,'ymin':0, 'ymax':1, 'grid': True,    'gridaxis': 'both', 'plot_title': plot_title[id],
            'traces':trace[id]
            }    
   plots.append(iplot)

ids = range(len(y_vars_sim))   
subfigs={ids: plots for ids, plots in zip(ids, plots)}
fig,axs=plotExp.plotExp(figs,subfigs,figfiles)




